Learn R Programming

biclust (version 2.0.3.1)

jaccardind: Jaccardind

Description

An adaption of the Jaccard Index for clustering is calculated.

Usage

jaccardind(bicres1,bicres2)
jaccard2(Rows, Cols)

Value

jaccardind calculates the Jaccard index

jaccard2 returns a similarity matrix containing the Jaccard index between all biclusters (upper triangle matrix)

Arguments

bicres1

A object of class Biclust

bicres2

A object of class Biclust

Rows

Matrix containing rows of biclusters

Cols

Matrix containing cols of biclusters

Author

Sebastian Kaiser [email protected]

Details

The function calculates the percentage of datapoints in the same bicluster structure from all datapoints at least included in one bicluster.

Examples

Run this code
if (FALSE) {
data(BicatYeast)
res1<-biclust(BicatYeast, method=BCPlaid(), back.fit = 2, shuffle = 3,
  fit.model = ~m + a + b,iter.startup = 5, iter.layer = 30,  verbose = TRUE)
res2<-biclust(BicatYeast, method=BCCC())
jaccardind(res1,res2)

}

Run the code above in your browser using DataLab